@@ -36,3 +36,27 @@ class MachineInterfaceError(Exception):
 
     def __str__(self):
         return self.message
+
+
+class MachineStateTransitionError(Exception):
+    def __init__(self, message):
+        self.message = message
+
+    def __str__(self):
+        return self.message
+
+
+class MachineInvalidStateError(Exception):
+    def __init__(self, message):
+        self.message = message
+
+    def __str__(self):
+        return self.message
+
+
+class MissingApiTokenError(Exception):
+    def __init__(self, message):
+        self.message = message
+
+    def __str__(self):
+        return self.message
